@@ -28,14 +28,12 @@ Config <- struct(
   sleep_delay = NULL,
   disable_rest_protocol_uri_cleaning = FALSE,
   sts_regional_endpoint = "",
-  signature_version = ""
+  signature_version = "",
+  partition_name = ""
 )
 
 # A Session object stores configuration and request handlers for a service.
-Session <- struct(
-  config = Config(),
-  handlers = Handlers()
-)
+Session <- struct(config = Config(), handlers = Handlers())
 
 # A ClientConfig object stores the information required to configure a service
 # client instance.
@@ -81,6 +79,22 @@ new_session <- function() {
 # only add host_prefix that match HOST_PREFIX_RE
 # https://github.com/boto/botocore/blob/786396c9b236671cc57f6404d84c381ad1499cc5/botocore/serialize.py#L173-L203
 HOST_PREFIX_RE <- "^[A-Za-z0-9\\.\\-]+$"
+GLOBAL_REGIONS <- c(
+  "aws-global",
+  "aws-cn-global",
+  "aws-us-gov-global",
+  "aws-iso-global",
+  "aws-iso-b-global"
+)
+PARTITIONS <- c(
+  "aws" = "^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$",
+  "aws-cn" = "^cn\\-\\w+\\-\\d+$",
+  "aws-us-gov" = "^us\\-gov\\-\\w+\\-\\d+$",
+  "aws-iso" = "^us\\-iso\\-\\w+\\-\\d+$",
+  "aws-iso-b" = "^us\\-isob\\-\\w+\\-\\d+$",
+  "aws-iso-e" = "^eu\\-isoe\\-\\w+\\-\\d+$",
+  "aws-iso-f" = "^us\\-isof\\-\\w+\\-\\d+$"
+)
 
 # resolver_endpoint returns the endpoint for a given service.
 # e.g. "https://ec2.us-east-1.amazonaws.com"
@@ -90,25 +104,27 @@ resolver_endpoint <- function(
   endpoints,
   sts_regional_endpoint = "",
   scheme = "https",
-  host_prefix = ""
+  host_prefix = "",
+  partition_name = ""
 ) {
   switch(
     vendor_cache[["vendor"]],
     "boto" = resolver_endpoint_boto(
-      service,
-      region,
-      endpoints,
-      sts_regional_endpoint,
-      scheme,
-      host_prefix
+      service = service,
+      region = region,
+      endpoints = endpoints,
+      sts_regional_endpoint = sts_regional_endpoint,
+      scheme = scheme,
+      host_prefix = host_prefix,
+      partition_name = partition_name
     ),
     "js" = resolver_endpoint_js(
-      service,
-      region,
-      endpoints,
-      sts_regional_endpoint,
-      scheme,
-      host_prefix
+      service = service,
+      region = region,
+      endpoints = endpoints,
+      sts_regional_endpoint = sts_regional_endpoint,
+      scheme = scheme,
+      host_prefix = host_prefix
     )
   )
 }
@@ -119,39 +135,36 @@ resolver_endpoint_boto <- function(
   endpoints,
   sts_regional_endpoint,
   scheme,
-  host_prefix
+  host_prefix,
+  partition_name
 ) {
-  # locate global endpoint
+  # Set default region for s3 if not provided
+  # https://github.com/boto/botocore/blob/develop/botocore/regions.py#L200-L205
+  if (service == 's3' && !nzchar(region)) region <- 'us-east-1'
   global_found <- check_global(endpoints)
-  global_region <- region == "aws-global"
-  if (!any(global_found) & global_region) {
+  global_endpoints <- global_found[global_found]
+
+  # use first global endpoint if region isn't provided
+  if (!nzchar(region) && length(global_endpoints) > 0) {
+    region <- names(global_endpoints)[1]
+  }
+
+  global_region <- region %in% GLOBAL_REGIONS
+  if (!any(global_found) && global_region) {
     stop("No region provided and no global region found.")
   }
-  signing_region <- (
-    if (any(global_found) & global_region)
-      names(global_found[global_found][1]) else region
-  )
-  e <- endpoints[[get_region_pattern(names(endpoints), signing_region)]]
+  e <- get_region_pattern(endpoints, region, partition_name)
   if (service == "sts" & nzchar(sts_regional_endpoint)) {
-    e$endpoint <- set_sts_regional_endpoint(
-      sts_regional_endpoint,
-      e
-    )
-    region <- set_sts_region(sts_regional_endpoint, region)
+    e[["endpoint"]] <- set_sts_regional_endpoint(sts_regional_endpoint, e[["endpoint"]])
+    e[["signing_region"]] <- set_sts_region(sts_regional_endpoint, region)
   }
-  # signing_region <- if (e[["global"]]) "us-east-1" else region
-  endpoint <- endpoint_unescape(e[["endpoint"]], signing_region)
+  endpoint <- endpoint_unescape(e[["endpoint"]], e[["signing_region"]])
   if (grepl(HOST_PREFIX_RE, host_prefix)) {
     endpoint <- sprintf("%s%s", host_prefix, endpoint)
   }
   endpoint <- gsub("^(.+://)?", sprintf("%s://", scheme), endpoint)
 
-  return(
-    list(
-      endpoint = endpoint,
-      signing_region = signing_region
-    )
-  )
+  return(list(endpoint = endpoint, signing_region = e[["signing_region"]]))
 }
 
 # Support paws < 0.8.0
@@ -165,28 +178,21 @@ resolver_endpoint_js <- function(
 ) {
   # Set default region for s3:
   # https://github.com/boto/botocore/blob/develop/botocore/regions.py#L189-L220
-  if (service == "s3" & (region == "aws-global")) {
-    region <- "us-east-1"
-  }
+  if (service == 's3' && !nzchar(region)) region <- 'us-east-1'
   # locate global endpoint
   global_found <- check_global(endpoints)
   global_region <- (region == "aws-global")
   if (!any(global_found) & global_region) {
     stop("No region provided and no global region found.")
   }
-  search_region <- (
-    if (any(global_found) & global_region)
-      names(global_found[global_found][1]) else region
-  )
+  search_region <- (if (any(global_found) & global_region)
+    names(global_found[global_found][1]) else region)
   e <- endpoints[[get_region_pattern_js(names(endpoints), search_region)]]
   if (is.character(e)) {
     e <- list(endpoint = e, global = FALSE)
   }
   if (service == "sts" & nzchar(sts_regional_endpoint)) {
-    e$endpoint <- set_sts_regional_endpoint(
-      sts_regional_endpoint,
-      e
-    )
+    e$endpoint <- set_sts_regional_endpoint(sts_regional_endpoint, e)
     region <- set_sts_region(sts_regional_endpoint, region)
   }
   signing_region <- if (e[["global"]]) "us-east-1" else region
@@ -196,12 +202,7 @@ resolver_endpoint_js <- function(
   }
   endpoint <- gsub("^(.+://)?", sprintf("%s://", scheme), endpoint)
 
-  return(
-    list(
-      endpoint = endpoint,
-      signing_region = signing_region
-    )
-  )
+  return(list(endpoint = endpoint, signing_region = signing_region))
 }
 
 set_sts_regional_endpoint <- function(sts_regional_endpoint, endpoint) {
@@ -217,7 +218,30 @@ set_sts_region <- function(sts_regional_endpoint, region) {
   switch(sts_regional_endpoint, "legacy" = "us-east-1", "regional" = region)
 }
 
-# client_config returns a ClientConfig configured for the service.
+get_region_pattern <- function(endpoints, region, partition_name = "") {
+  if (nzchar(partition_name)) {
+    found <- PARTITIONS[names(PARTITIONS) == partition_name]
+  } else {
+    nms <- names(endpoints)
+    found <- nms[nms == region]
+    if (length(found) == 0) {
+      partition_name <- set_partition_name(region)
+      found <- PARTITIONS[names(PARTITIONS) == partition_name]
+    }
+  }
+  result <- list()
+  if (length(found) > 0) {
+    result <- endpoints[[found]]
+  } else {
+    # default to partition "aws" when no region is found
+    # https://github.com/boto/botocore/blob/develop/botocore/client.py#L638-L647
+    result <- endpoints[["^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$"]]
+  }
+
+  if (is.null(result[["signing_region"]])) result[["signing_region"]] <- region
+  return(result)
+}
+
 # client_config returns a ClientConfig configured for the service.
 client_config <- function(
   service_name,
@@ -228,41 +252,37 @@ client_config <- function(
 ) {
   sess <- new_session()
   if (!is.null(cfgs)) {
-    sess$config <- cfgs
+    sess[["config"]] <- cfgs
   }
   custom_endpoint <- FALSE
-  # If region not defined, set it
-  if (nchar(sess$config$region) == 0) {
-    sess$config$region <- get_region(sess$config[["credentials"]][["profile"]])
-  }
-  signing_region <- sess$config$region
-  if (sess$config$endpoint != "") {
-    endpoint <- sess$config$endpoint
+  signing_region <- sess[["config"]][["region"]]
+  if (sess[["config"]][["endpoint"]] != "") {
+    endpoint <- sess[["config"]][["endpoint"]]
   } else {
     endpoint <- get_service_endpoint(
-      sess$config[["credentials"]][["profile"]],
+      sess[["config"]][["credentials"]][["profile"]],
       service_id
     )
     if (!is.null(endpoint)) {
       custom_endpoint <- TRUE
     } else {
-      sts_regional_endpoint <- sess$config$sts_regional_endpoint
       re <- resolver_endpoint(
         service_name,
         signing_region,
         endpoints,
-        sts_regional_endpoint,
-        host_prefix = operation$host_prefix
+        sess[["config"]][["sts_regional_endpoint"]],
+        host_prefix = operation[["host_prefix"]],
+        partition_name = sess[["config"]][["partition_name"]]
       )
-      endpoint <- re$endpoint
-      signing_region <- re$signing_region
+      endpoint <- re[["endpoint"]]
+      signing_region <- re[["signing_region"]]
     }
     # sess$config$endpoint <- endpoint
     # sess$config$region <- signing_region
   }
   cc <- ClientConfig(
-    config = sess$config,
-    handlers = sess$handlers,
+    config = sess[["config"]],
+    handlers = sess[["handlers"]],
     endpoint = endpoint,
     custom_endpoint = custom_endpoint,
     signing_region = signing_region,
