@@ -156,14 +156,24 @@ config_file_provider <- function(profile = "") {
 
     if ("credential_source" %in% profile_nms) {
       credential_source <- profile$credential_source
-      creds <- config_file_credential_source(role_arn, role_session_name, mfa_serial, credential_source)
+      creds <- config_file_credential_source(
+        role_arn,
+        role_session_name,
+        mfa_serial,
+        credential_source
+      )
       if (!is.null(creds)) {
         return(creds)
       }
     }
     if ("source_profile" %in% profile_nms) {
       source_profile <- profile$source_profile
-      creds <- config_file_source_profile(role_arn, role_session_name, mfa_serial, source_profile)
+      creds <- config_file_source_profile(
+        role_arn,
+        role_session_name,
+        mfa_serial,
+        source_profile
+      )
       if (!is.null(creds)) {
         return(creds)
       }
@@ -174,7 +184,11 @@ config_file_provider <- function(profile = "") {
     if ("web_identity_token_file" %in% profile_nms) {
       web_identity_token_file <- profile$web_identity_token_file
       web_identity_token <- get_web_identity_token(web_identity_token_file)
-      creds <- get_assume_role_with_web_identity_creds(role_arn, role_session_name, web_identity_token)
+      creds <- get_assume_role_with_web_identity_creds(
+        role_arn,
+        role_session_name,
+        web_identity_token
+      )
       if (!is.null(creds)) {
         return(creds)
       }
@@ -195,8 +209,12 @@ config_file_credential_process <- function(command) {
 
   access_key_id <- data$AccessKeyId
   secret_access_key <- data$SecretAccessKey
-  if (is.null(access_key_id) || access_key_id == "" ||
-    is.null(secret_access_key) || secret_access_key == "") {
+  if (
+    is.null(access_key_id) ||
+      access_key_id == "" ||
+      is.null(secret_access_key) ||
+      secret_access_key == ""
+  ) {
     return(NULL)
   }
 
@@ -218,7 +236,12 @@ config_file_credential_process <- function(command) {
 # Get the `role_arn`'s temporary credentials given a `credential_source`,
 # either "Environment", "Ec2InstanceMetadata", or "EcsContainer".
 # See https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-role.html
-config_file_credential_source <- function(role_arn, role_session_name, mfa_serial, credential_source) {
+config_file_credential_source <- function(
+  role_arn,
+  role_session_name,
+  mfa_serial,
+  credential_source
+) {
   if (credential_source == "Environment") {
     creds <- env_provider()
   } else if (credential_source == "Ec2InstanceMetadata") {
@@ -233,102 +256,71 @@ config_file_credential_source <- function(role_arn, role_session_name, mfa_seria
   return(role_creds)
 }
 
-aws_sso_cmd <- function(profile_name, msg) {
-  cmd <- c("sso", "login", "--profile", profile_name)
-  log_warn(msg, paste("aws", paste(cmd, collapse = " ")))
-  tf <- tempfile()
-  on.exit(unlink(tf))
-  system2("aws", cmd, stderr = tf)
-  if (file.exists(tf) && length(error <- readLines(tf)) > 0) {
-    stop(error, call. = FALSE)
-  }
-}
-
 # Get credentials from profile associated with an SSO login.  Assumes
 # the user has already logged in via e.g. the aws cli so that a cached
 # access token is available.
-sso_credential_process <- function(sso_session,
-                                   sso_start_url,
-                                   sso_account_id,
-                                   sso_region,
-                                   sso_role_name,
-                                   profile_name,
-                                   retry_no = 0) {
+sso_credential_process <- function(
+  sso_session,
+  sso_start_url,
+  sso_account_id,
+  sso_region,
+  sso_role_name,
+  profile_name
+) {
   input_str <- sso_session %||% sso_start_url
   cache_key <- digest::digest(enc2utf8(input_str), algo = "sha1", serialize = FALSE)
   json_file <- paste0(cache_key, ".json")
-  root <- switch(Sys.info()[[1]],
+  root <- switch(
+    Sys.info()[[1]],
     "Windows" = file.path(Sys.getenv("HOMEDRIVE"), Sys.getenv("HOMEPATH")),
     "~"
   )
   sso_cache <- file.path(root, ".aws", "sso", "cache", json_file)
   if (!file.exists(sso_cache)) {
-    msg <- "Error loading SSO Token: Token for %s does not exist"
-    if (!isTRUE(getOption("paws.aws_sso_creds"))) {
-      log_info(
-        "Set `options(paws.aws_sso_creds = TRUE)` to turn on sso credentials automation"
-      )
-      stopf(msg, input_str)
-    }
-    log_error(msg, input_str)
-    aws_sso_cmd(
-      sub("profile ", "", profile_name, fixed = TRUE),
-      "Attempting to set credentials using: `%s`"
+    msg <- paste(
+      "Error loading SSO Token: Token for %s does not exist",
+      "Try refreshing sso credentials: `aws sso login --profile %s`",
+      sep = "\n"
     )
+    stopf(msg, input_str, sub("profile ", "", profile_name))
   }
   cache_creds <- jsonlite::fromJSON(sso_cache)
-  if (!("accessToken" %in% names(cache_creds)) || !("expiresAt" %in% names(cache_creds))) {
-    stopf(
+  if (
+    !("accessToken" %in% names(cache_creds)) || !("expiresAt" %in% names(cache_creds))
+  ) {
+    msg <- paste(
       "Error loading SSO Token: Token for %s is invalid.",
-      sso_start_url
+      "Try refreshing sso credentials: `aws sso login --profile %s`",
+      sep = "\n"
     )
+    stopf(msg, sso_start_url, sub("profile ", "", profile_name))
   }
   svc <- sso(
     config = list(
-      credentials = list(
-        creds = list(
-          access_token = cache_creds$accessToken
-        )
-      ),
+      credentials = list(creds = list(access_token = cache_creds$accessToken)),
       region = sso_region,
       endpoint = "",
       close_connection = FALSE,
       disable_rest_protocol_uri_cleaning = TRUE
     )
   )
-  retry_resp <- NULL
   tryCatch(
-    resp <- svc$get_role_credentials(sso_role_name, sso_account_id, cache_creds$accessToken),
+    resp <- svc$get_role_credentials(
+      sso_role_name,
+      sso_account_id,
+      cache_creds$accessToken
+    ),
     http_401 = function(err) {
       if (grepl("Session token not found or invalid", err$error_response$message)) {
-        profile <- sub("profile ", "", profile_name, fixed = TRUE)
-        if (retry_no == 1 || (!isTRUE(getOption("paws.aws_sso_creds")))) {
-          enrich_msg <- sprintf(
-            "Try refreshing sso credentials: `aws sso login --profile %s`", profile
-          )
-          err$message <- paste(err$message, enrich_msg, sep = "\n")
-          log_info(
-            "Set `options(paws.aws_sso_creds = TRUE)` to turn on sso credentials automation"
-          )
-          stop(err)
-        }
-        log_error(err$error_response$message)
-        aws_sso_cmd(profile, "Attempting to refresh credentials using: `%s`")
-        retry_resp <<- sso_credential_process(
-          sso_session,
-          sso_start_url,
-          sso_account_id,
-          sso_region,
-          sso_role_name,
-          profile_name,
-          1
+        enrich_msg <- sprintf(
+          "Try refreshing sso credentials: `aws sso login --profile %s`",
+          sub("profile ", "", profile_name, fixed = TRUE)
         )
+        err$message <- paste(err$message, enrich_msg, sep = "\n")
       }
+      stop(err)
     }
   )
-  if (!is.null(retry_resp)) {
-    return(retry_resp)
-  }
 
   if (is.null(resp)) {
     return(NULL)
@@ -345,7 +337,12 @@ sso_credential_process <- function(sso_session,
 # Get STS temporary credentials for the role with ARN `role_arn` using
 # credentials found in profile named `source_profile`.
 # See https://docs.aws.amazon.com/credref/latest/refdocs/setting-global-source_profile.html.
-config_file_source_profile <- function(role_arn, role_session_name, mfa_serial, source_profile) {
+config_file_source_profile <- function(
+  role_arn,
+  role_session_name,
+  mfa_serial,
+  source_profile
+) {
   creds <- credentials_file_provider(source_profile)
   if (is.null(creds)) creds <- config_file_provider(source_profile)
   if (is.null(creds)) {
@@ -384,10 +381,7 @@ get_creds_from_sts_resp <- function(resp) {
 get_assumed_role_creds <- function(role_arn, role_session_name, mfa_serial, creds) {
   svc <- sts(config = list(credentials = list(creds = creds)))
   if (is.null(mfa_serial) || mfa_serial == "") {
-    resp <- svc$assume_role(
-      RoleArn = role_arn,
-      RoleSessionName = role_session_name
-    )
+    resp <- svc$assume_role(RoleArn = role_arn, RoleSessionName = role_session_name)
   } else {
     token_code <- get_token_code()
     resp <- svc$assume_role(
@@ -405,7 +399,11 @@ get_assumed_role_creds <- function(role_arn, role_session_name, mfa_serial, cred
 }
 
 # Get STS credentials for AssumeRoleWithWebIdentity
-get_assume_role_with_web_identity_creds <- function(role_arn, role_session_name, web_identity_token) {
+get_assume_role_with_web_identity_creds <- function(
+  role_arn,
+  role_session_name,
+  web_identity_token
+) {
   svc <- sts(config = list(credentials = list(anonymous = TRUE)))
 
   resp <- svc$assume_role_with_web_identity(
@@ -432,7 +430,8 @@ container_credentials_provider <- function() {
   # Look for job role credentials first, then web identity token file
   if (container_credentials_uri != "" || container_credentials_full_uri != "") {
     credentials_response <- get_container_credentials(
-      container_credentials_uri, container_credentials_full_uri
+      container_credentials_uri,
+      container_credentials_full_uri
     )
   } else if (container_credentials_token != "") {
     credentials_response <- get_container_credentials_eks()
@@ -445,9 +444,7 @@ container_credentials_provider <- function() {
 
   # return credential
   if (is.null(access_key_id) || is.null(secret_access_key) || is.null(session_token)) {
-    log_info(
-      "Unable to obtain access_key_id, secret_access_key or session_token"
-    )
+    log_info("Unable to obtain access_key_id, secret_access_key or session_token")
     return(NULL)
   }
 
@@ -490,17 +487,14 @@ get_container_credentials <- function(credentials_uri, credentials_full_uri) {
     return(NULL)
   }
 
-  credentials_response_body <-
-    jsonlite::fromJSON(raw_to_utf8(metadata_response$body))
+  credentials_response_body <- jsonlite::fromJSON(raw_to_utf8(metadata_response$body))
 
-  return(
-    list(
-      access_key_id = credentials_response_body$AccessKeyId,
-      secret_access_key = credentials_response_body$SecretAccessKey,
-      session_token = credentials_response_body$Token,
-      expiration = as_timestamp(credentials_response_body$Expiration, "iso8601")
-    )
-  )
+  return(list(
+    access_key_id = credentials_response_body$AccessKeyId,
+    secret_access_key = credentials_response_body$SecretAccessKey,
+    session_token = credentials_response_body$Token,
+    expiration = as_timestamp(credentials_response_body$Expiration, "iso8601")
+  ))
 }
 
 # Developed from:
@@ -510,7 +504,11 @@ set_container_credentails_headers <- function() {
   ENV_VAR_AUTH_TOKEN <- get_env("AWS_CONTAINER_AUTHORIZATION_TOKEN")
   ENV_VAR_AUTH_TOKEN_FILE <- get_env("AWS_CONTAINER_AUTHORIZATION_TOKEN_FILE")
   if (ENV_VAR_AUTH_TOKEN_FILE != "") {
-    auth_token[["Authorization"]] <- readLines(ENV_VAR_AUTH_TOKEN_FILE, encoding = "utf-8", warn = FALSE)
+    auth_token[["Authorization"]] <- readLines(
+      ENV_VAR_AUTH_TOKEN_FILE,
+      encoding = "utf-8",
+      warn = FALSE
+    )
   } else if (ENV_VAR_AUTH_TOKEN != "") {
     auth_token[["Authorization"]] <- ENV_VAR_AUTH_TOKEN
   }
@@ -524,13 +522,11 @@ set_container_credentails_headers <- function() {
 }
 
 get_container_credentials_eks <- function() {
-  return(
-    get_assume_role_with_web_identity_creds(
-      role_arn = get_role_arn(),
-      role_session_name = get_role_session_name(),
-      web_identity_token = get_web_identity_token()
-    )
-  )
+  return(get_assume_role_with_web_identity_creds(
+    role_arn = get_role_arn(),
+    role_session_name = get_role_session_name(),
+    web_identity_token = get_web_identity_token()
+  ))
 }
 
 # Retrieve credentials for EC2 IAM Role
@@ -557,16 +553,12 @@ iam_credentials_provider <- function() {
   session_token <- credentials_response_body$Token
   expiration <- as_timestamp(credentials_response_body$Expiration, "iso8601")
 
-  if (is.null(access_key_id) || is.null(secret_access_key) ||
-    is.null(session_token)) {
-    log_info(
-      "Unable to obtain access_key_id, secret_access_key or session_token"
-    )
+  if (is.null(access_key_id) || is.null(secret_access_key) || is.null(session_token)) {
+    log_info("Unable to obtain access_key_id, secret_access_key or session_token")
     return(NULL)
   }
 
-  if (access_key_id != "" && secret_access_key != "" &&
-    session_token != "") {
+  if (access_key_id != "" && secret_access_key != "" && session_token != "") {
     creds <- Creds(
       access_key_id = access_key_id,
       secret_access_key = secret_access_key,
@@ -581,11 +573,10 @@ iam_credentials_provider <- function() {
 }
 
 no_credentials <- function() {
-  message <- (
-    if (isTRUE(getOption("paws.log_level") <= 2L)) {
-      'No compatible credentials provided. Use `options("paws.log_level" = 3L)` for more information.'
-    } else {
-      "No compatible credentials provided."
-    })
+  message <- (if (isTRUE(getOption("paws.log_level") <= 2L)) {
+    'No compatible credentials provided. Use `options("paws.log_level" = 3L)` for more information.'
+  } else {
+    "No compatible credentials provided."
+  })
   stop(message, call. = FALSE)
 }
