@@ -1,20 +1,23 @@
 # Returns a credentials object with a test credential provider.
 test_creds <- Credentials(
-  provider = list(
-    function() {
-      list(
-        access_key_id = "AKID",
-        secret_access_key = "SECRET",
-        session_token = "SESSION",
-        provider_name = "StaticProvider"
-      )
-    }
-  )
+  provider = list(function() {
+    list(
+      access_key_id = "AKID",
+      secret_access_key = "SECRET",
+      session_token = "SESSION",
+      provider_name = "StaticProvider"
+    )
+  })
 )
 
 test_that("v4_sign_request_handler", {
   metadata <- list(
-    endpoints = list("^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(endpoint = "s3.amazonaws.com", global = FALSE)),
+    endpoints = list(
+      "^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(
+        endpoint = "s3.amazonaws.com",
+        global = FALSE
+      )
+    ),
     service_name = "s3"
   )
   client <- new_service(metadata, new_handlers("restxml", "s3"), Config())
@@ -36,10 +39,7 @@ test_that("sign with custom URI escape", {
   expected <- "AWS4-HMAC-SHA256 Credential=AKID/19700101/us-east-1/es/aws4_request, SignedHeaders=host;x-amz-date;x-amz-security-token, Signature=6601e883cc6d23871fd6c2a394c5677ea2b8c82b04a6446786d64cd74f520967"
 
   creds <- test_creds
-  signer <- Signer(
-    credentials = creds,
-    disable_uri_path_escaping = TRUE
-  )
+  signer <- Signer(credentials = creds, disable_uri_path_escaping = TRUE)
 
   host <- "https://subdomain.us-east-1.es.amazonaws.com"
   req <- new_http_request("GET", host, NULL)
@@ -111,7 +111,16 @@ test_that("standalone presign with port", {
   for (case in cases) {
     signer <- Signer(test_creds)
     req <- new_http_request("GET", case$url, NULL)
-    req <- sign_with_body(signer, req, NULL, "es", "us-east-1", 5 * 60, TRUE, unix_time(0, 0))
+    req <- sign_with_body(
+      signer,
+      req,
+      NULL,
+      "es",
+      "us-east-1",
+      5 * 60,
+      TRUE,
+      unix_time(0, 0)
+    )
     query_params <- parse_query_string(req$url$raw_query)
     actual <- query_params[["X-Amz-Signature"]]
     expect_equal(actual, case$expected)
@@ -126,35 +135,56 @@ test_that("presign", {
   req$header["Content-Type"] <- "application/x-amz-json-1.0"
   req$header["Content-Length"] <- length(charToRaw(req$body))
   req$header["X-Amz-Meta-Other-Header"] <- "some-value=!@#$%^&* (+)"
-  req$header[["X-Amz-Meta-Other-Header_With_Underscore"]] <- c("some-value=!@#$%^&* (+)", "some-value=!@#$%^&* (+)")
-  req <- sign_with_body(signer, req, "{}", "dynamodb", "us-east-1", 300, TRUE, unix_time(0, 0))
+  req$header[["X-Amz-Meta-Other-Header_With_Underscore"]] <- c(
+    "some-value=!@#$%^&* (+)",
+    "some-value=!@#$%^&* (+)"
+  )
+  req <- sign_with_body(
+    signer,
+    req,
+    "{}",
+    "dynamodb",
+    "us-east-1",
+    300,
+    TRUE,
+    unix_time(0, 0)
+  )
 
   q <- parse_query_string(req$url$raw_query)
 
-  expect_equal(q[["X-Amz-Signature"]], "122f0b9e091e4ba84286097e2b3404a1f1f4c4aad479adda95b7dff0ccbe5581")
+  expect_equal(
+    q[["X-Amz-Signature"]],
+    "122f0b9e091e4ba84286097e2b3404a1f1f4c4aad479adda95b7dff0ccbe5581"
+  )
   expect_equal(q[["X-Amz-Credential"]], "AKID/19700101/us-east-1/dynamodb/aws4_request")
-  expect_equal(q[["X-Amz-SignedHeaders"]], "content-length;content-type;host;x-amz-meta-other-header;x-amz-meta-other-header_with_underscore")
+  expect_equal(
+    q[["X-Amz-SignedHeaders"]],
+    "content-length;content-type;host;x-amz-meta-other-header;x-amz-meta-other-header_with_underscore"
+  )
   expect_equal(q[["X-Amz-Date"]], "19700101T000000Z")
   expect_equal(q[["X-Amz-Target"]], "prefix.Operation")
 })
 
 anonymous_test_creds <- Credentials(
   anonymous = TRUE,
-  provider = list(
-    function() {
-      list(
-        access_key_id = "",
-        secret_access_key = "",
-        session_token = "",
-        provider_name = ""
-      )
-    }
-  )
+  provider = list(function() {
+    list(
+      access_key_id = "",
+      secret_access_key = "",
+      session_token = "",
+      provider_name = ""
+    )
+  })
 )
 
 test_that("Test anonymous credentials", {
   metadata <- list(
-    endpoints = list("^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(endpoint = "s3.amazonaws.com", global = FALSE)),
+    endpoints = list(
+      "^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(
+        endpoint = "s3.amazonaws.com",
+        global = FALSE
+      )
+    ),
     service_name = "s3"
   )
   client <- new_service(metadata, new_handlers("restxml", "s3"), Config())
